==> python-pytorch-2.8.0-8-x86_64.pkg.tar.zst: usr/lib/python3.13/site-packages/torch/_higher_order_ops/__init__.py <==
from torch._higher_order_ops._invoke_quant import (
    invoke_quant,
    invoke_quant_packed,
    InvokeQuant,
)
from torch._higher_order_ops.aoti_call_delegate import aoti_call_delegate
from torch._higher_order_ops.associative_scan import associative_scan
from torch._higher_order_ops.auto_functionalize import (
    auto_functionalized,
    auto_functionalized_v2,
)
from torch._higher_order_ops.base_hop import BaseHOP
from torch._higher_order_ops.cond import cond
from torch._higher_order_ops.effects import with_effects
from torch._higher_order_ops.executorch_call_delegate import executorch_call_delegate
from torch._higher_order_ops.flat_apply import flat_apply
from torch._higher_order_ops.flex_attention import (
    flex_attention,
    flex_attention_backward,
)
from torch._higher_order_ops.foreach_map import _foreach_map, foreach_map
from torch._higher_order_ops.hints_wrap import hints_wrapper
from torch._higher_order_ops.invoke_subgraph import invoke_subgraph
from torch._higher_order_ops.map import map
from torch._higher_order_ops.out_dtype import out_dtype
from torch._higher_order_ops.run_const_graph import run_const_graph
from torch._higher_order_ops.scan import scan
from torch._higher_order_ops.strict_mode import strict_mode
from torch._higher_order_ops.torchbind import call_torchbind
from torch._higher_order_ops.while_loop import while_loop
from torch._higher_order_ops.wrap import (
    dynamo_bypassing_wrapper,
    tag_activation_checkpoint,
    wrap_activation_checkpoint,
    wrap_with_autocast,
    wrap_with_set_grad_enabled,
)


__all__ = [
    "cond",
    "while_loop",
    "invoke_subgraph",
    "scan",
    "map",
    "flex_attention",
    "flex_attention_backward",
    "hints_wrapper",
    "BaseHOP",
    "flat_apply",
    "foreach_map",
    "_foreach_map",
    "with_effects",
    "tag_activation_checkpoint",
    "auto_functionalized",
    "auto_functionalized_v2",
    "associative_scan",
    "out_dtype",
    "executorch_call_delegate",
    "call_torchbind",
    "run_const_graph",
    "InvokeQuant",
    "invoke_quant",
    "invoke_quant_packed",
    "wrap_with_set_grad_enabled",
    "wrap_with_autocast",
    "wrap_activation_checkpoint",
    "dynamo_bypassing_wrapper",
    "strict_mode",
    "aoti_call_delegate",
    "map",
]

==> python-pytorch-2.9.1-7-x86_64.pkg.tar.zst: usr/lib/python3.14/site-packages/torch/_higher_order_ops/__init__.py <==
from torch._higher_order_ops._invoke_quant import (
    invoke_quant,
    invoke_quant_packed,
    InvokeQuant,
)
from torch._higher_order_ops.aoti_call_delegate import aoti_call_delegate
from torch._higher_order_ops.associative_scan import associative_scan
from torch._higher_order_ops.auto_functionalize import (
    auto_functionalized,
    auto_functionalized_v2,
)
from torch._higher_order_ops.base_hop import BaseHOP
from torch._higher_order_ops.cond import cond
from torch._higher_order_ops.effects import with_effects
from torch._higher_order_ops.executorch_call_delegate import executorch_call_delegate
from torch._higher_order_ops.flat_apply import flat_apply
from torch._higher_order_ops.flex_attention import (
    flex_attention,
    flex_attention_backward,
)
from torch._higher_order_ops.foreach_map import _foreach_map, foreach_map
from torch._higher_order_ops.hints_wrap import hints_wrapper
from torch._higher_order_ops.invoke_subgraph import invoke_subgraph
from torch._higher_order_ops.map import map
from torch._higher_order_ops.out_dtype import out_dtype
from torch._higher_order_ops.run_const_graph import run_const_graph
from torch._higher_order_ops.scan import scan
from torch._higher_order_ops.strict_mode import strict_mode
from torch._higher_order_ops.torchbind import call_torchbind
from torch._higher_order_ops.while_loop import (
    while_loop,
    while_loop_stack_output_op as while_loop_stack_output,
)
from torch._higher_order_ops.wrap import (
    dynamo_bypassing_wrapper,
    tag_activation_checkpoint,
    wrap_activation_checkpoint,
    wrap_with_autocast,
    wrap_with_set_grad_enabled,
)


__all__ = [
    "cond",
    "while_loop",
    "invoke_subgraph",
    "scan",
    "map",
    "flex_attention",
    "flex_attention_backward",
    "hints_wrapper",
    "BaseHOP",
    "flat_apply",
    "foreach_map",
    "_foreach_map",
    "with_effects",
    "tag_activation_checkpoint",
    "auto_functionalized",
    "auto_functionalized_v2",
    "associative_scan",
    "out_dtype",
    "executorch_call_delegate",
    "call_torchbind",
    "run_const_graph",
    "InvokeQuant",
    "invoke_quant",
    "invoke_quant_packed",
    "wrap_with_set_grad_enabled",
    "wrap_with_autocast",
    "wrap_activation_checkpoint",
    "dynamo_bypassing_wrapper",
    "strict_mode",
    "aoti_call_delegate",
    "map",
    "while_loop_stack_output",
]
